/*--------------------------------------------------------------------------+
$Id: BoundedIntPositiveZeroValidator.java 21071 2017-10-09 13:06:34Z hoelzl $
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.properties;

import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;
import org.fortiss.tooling.base.ui.databinding.NumberPositiveZeroValidator;

/**
 * A {@link NumberPositiveZeroValidator} with boundary checking for int values.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 21071 $
 * @ConQAT.Rating RED Hash:
 */
public class BoundedIntPositiveZeroValidator extends NumberPositiveZeroValidator {
	/** The lower bound. */
	private final int lowerBound;
	/** The upper bound. */
	private final int upperBound;

	/** Constructor. */
	public BoundedIntPositiveZeroValidator(int lower, int upper) {
		this.lowerBound = lower;
		this.upperBound = upper;
	}

	/** {@inheritDoc} */
	@Override
	public IStatus validate(Object value) {
		IStatus status = super.validate(value);
		if(status == ValidationStatus.ok()) {
			double dval = ((Number)value).doubleValue();
			if(dval >= lowerBound && dval <= upperBound) {
				return ValidationStatus.ok();
			}
			return ValidationStatus.cancel("Value must be between " + lowerBound + " and " +
					upperBound + "!");
		}
		return status;
	}
}
