/*--------------------------------------------------------------------------+
$Id: UIDUnitPropertySection.java 22342 2017-11-30 13:18:55Z hoelzl $
|                                                                          |
| Copyright 2013 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.properties;

import static org.eclipse.jface.databinding.swt.SWTObservables.observeText;
import static org.fortiss.tooling.kernel.ui.util.ObservableUtils.observeValue;

import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
import org.fortiss.af3.platform.raspberry.model.brick.BrickPackage;
import org.fortiss.af3.platform.raspberry.model.brick.UIDUnit;
import org.fortiss.tooling.kernel.ui.extension.base.PropertySectionBase;

/**
 * Property section for {@link UIDUnit}s.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 22342 $
 * @ConQAT.Rating GREEN Hash: 9E768B733BD37201F97399293FA0DFA7
 */
public class UIDUnitPropertySection extends PropertySectionBase {
	/** The unit. */
	private UIDUnit unit;
	/** The unique ID widget. */
	private Text uidText;

	/** {@inheritDoc} */
	@Override
	public void createControls(Composite parent, TabbedPropertySheetPage tabbedPropertySheetPage) {
		super.createControls(parent, tabbedPropertySheetPage);
		uidText = createDecoratedText("UID");
	}

	/** {@inheritDoc} */
	@Override
	protected void setSectionInput(Object input) {
		unit = (UIDUnit)input;
	}

	/** {@inheritDoc} */
	@Override
	public void refresh() {
		super.refresh();
		IObservableValue modelObservable =
				observeValue(unit, BrickPackage.Literals.UID_UNIT__UNIQUE_BRICKLET_ID);
		dbc.bindValue(observeText(uidText, SWT.Modify), modelObservable);
	}
}
